#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import numpy as np
import matplotlib.pyplot as plt
import matplotlib as mpl

params={
          'text.latex.preamble' : r'\usepackage{amsmath}',
                'font.size':14, 'text.usetex': True,
                'axes.formatter.use_mathtext': True
                }

plt.rcParams.update(params)
plt.rcParams['image.cmap']=='viridis'
plt.rcParams["figure.figsize"] = (11.25,7.5)
plt.rcParams['axes.grid'] = True
plt.rc('xtick',labelsize=18)
plt.rc('ytick',labelsize=18)

font = {'family' : 'serif',
         'serif':  'cmr10'
         }

plt.rc('font', **font)
plt.rc('xtick',direction='in')
plt.rc('ytick',direction='in')
plt.rc('axes',unicode_minus=False)

def main():

    expDataFile = [
                 'data/paddleData/R01.conv.awd',
                 'data/paddleData/R05.conv.awd',
                 'data/paddleData/R12.conv.awd'
                 ]
    
    imgprefix='images/'
    
    n_lines = 4
    cmap = mpl.colormaps['viridis']
    colors = cmap(np.linspace(0, 0.8, n_lines))
    tsize = 24
    lsize = 18
    
    nChannels = 31
    headerLines = 20+9*nChannels+1
    freq = 50
    
    # Extract and plot the raw data
    plt.figure(dpi=300)
    
    for i in range(len(expDataFile)):
        pt,px,samp = getMakerData(expDataFile[i],nChannels,headerLines,freq)
        plt.plot(pt,px,color=colors[i],label=expDataFile[i][-12:-9],linewidth=2)

    plt.xlim(0,12)
    plt.xlabel('Time [s]',fontsize=tsize)
    plt.ylabel('Paddle Position [m]',fontsize=tsize)
    plt.title("Physical Wave Maker Input Signal",fontsize=tsize)
    plt.legend(loc='upper left',prop={'size':lsize})
    plt.tight_layout()
    plt.savefig(imgprefix+'Wave_Maker_Input_Signal.png',format='png')

def getMakerData(expDataFile,nChannels,headerLines,freq):
    px=[]
    with open(expDataFile) as fin:
        
        for i in range(headerLines):
            fin.readline()
            
        dataIn = fin.readlines()
        for line in dataIn:
            splitLn = line.split()
            px.append(float(splitLn[-1]))
            
        samp = len(px)
        pt = [1/freq*i for i in range(samp)]
        
    return np.round(np.asarray(pt),2),  np.asarray(px), samp
  
if __name__ == "__main__":
    main()